@@ -48,13 +48,13 @@ class herk_helper
   
   
   template<typename eT>
-  static
   arma_hot
   inline
+  static
   eT
   dot_conj_row(const uword n_elem, const eT* const A, const Mat<eT>& B, const uword row)
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     
     typedef typename get_pod_type<eT>::result T;
     
@@ -101,7 +101,7 @@ class herk_vec
     const T                       beta  = T(0)
     )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     
     typedef std::complex<T> eT;
     
@@ -242,7 +242,7 @@ class herk_emul
     const T                       beta  = T(0)
     )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     
     typedef std::complex<T> eT;
     
@@ -320,7 +320,7 @@ class herk
   void
   apply_blas_type( Mat<std::complex<T>>& C, const TA& A, const T alpha = T(1), const T beta = T(0) )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     
     const uword threshold = 16;
     
@@ -391,7 +391,7 @@ class herk
           return;
           }
         
-        arma_extra_debug_print("blas::herk()");
+        arma_debug_print("blas::herk()");
         
         const char uplo = 'U';
         
@@ -405,7 +405,7 @@ class herk
         
         const blas_int lda = (do_trans_A) ? k : n;
         
-        arma_extra_debug_print( arma_str::format("blas::herk(): trans_A = %c") % trans_A );
+        arma_debug_print( arma_str::format("blas::herk(): trans_A = %c") % trans_A );
         
         blas::herk<T>
           (
