@@ -32,7 +32,7 @@ inline
 void
 op_logmat::apply(Mat< std::complex<typename T1::elem_type> >& out, const mtOp<std::complex<typename T1::elem_type>,T1,op_logmat>& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool status = op_logmat::apply_direct(out, in.m, in.aux_uword_a);
   
@@ -50,13 +50,13 @@ inline
 bool
 op_logmat::apply_direct(Mat< std::complex<typename T1::elem_type> >& out, const Op<T1,op_diagmat>& expr, const uword)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type T;
   
   const diagmat_proxy<T1> P(expr.m);
   
-  arma_debug_check( (P.n_rows != P.n_cols), "logmat(): given matrix must be square sized" );
+  arma_conform_check( (P.n_rows != P.n_cols), "logmat(): given matrix must be square sized" );
   
   const uword N = P.n_rows;
   
@@ -86,7 +86,7 @@ inline
 bool
 op_logmat::apply_direct(Mat< std::complex<typename T1::elem_type> >& out, const Base<typename T1::elem_type,T1>& expr, const uword n_iters)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type       in_T;
   typedef typename std::complex<in_T> out_T;
@@ -94,7 +94,7 @@ op_logmat::apply_direct(Mat< std::complex<typename T1::elem_type> >& out, const
   const quasi_unwrap<T1> expr_unwrap(expr.get_ref());
   const Mat<in_T>& A   = expr_unwrap.M;
   
-  arma_debug_check( (A.is_square() == false), "logmat(): given matrix must be square sized" );
+  arma_conform_check( (A.is_square() == false), "logmat(): given matrix must be square sized" );
   
   if(A.n_elem == 0)
     {
@@ -111,7 +111,7 @@ op_logmat::apply_direct(Mat< std::complex<typename T1::elem_type> >& out, const
   
   if(A.is_diagmat())
     {
-    arma_extra_debug_print("op_logmat: detected diagonal matrix");
+    arma_debug_print("op_logmat: detected diagonal matrix");
     
     const uword N = A.n_rows;
     
@@ -138,7 +138,7 @@ op_logmat::apply_direct(Mat< std::complex<typename T1::elem_type> >& out, const
   
   if(try_sympd)
     {
-    arma_extra_debug_print("op_logmat: attempting sympd optimisation");
+    arma_debug_print("op_logmat: attempting sympd optimisation");
     
     // if matrix A is sympd, all its eigenvalues are positive
     
@@ -168,7 +168,7 @@ op_logmat::apply_direct(Mat< std::complex<typename T1::elem_type> >& out, const
         }
       }
     
-    arma_extra_debug_print("op_logmat: sympd optimisation failed");
+    arma_debug_print("op_logmat: sympd optimisation failed");
     
     // fallthrough if eigen decomposition failed or an eigenvalue is <= 0
     }
@@ -196,7 +196,7 @@ inline
 void
 op_logmat_cx::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_logmat_cx>& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool status = op_logmat_cx::apply_direct(out, in.m, in.aux_uword_a);
   
@@ -214,7 +214,7 @@ inline
 bool
 op_logmat_cx::apply_direct(Mat<typename T1::elem_type>& out, const Op<T1,op_diagmat>& expr, const uword)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
@@ -245,9 +245,9 @@ inline
 bool
 op_logmat_cx::apply_direct_noalias(Mat<typename T1::elem_type>& out, const diagmat_proxy<T1>& P)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (P.n_rows != P.n_cols), "logmat(): given matrix must be square sized" );
+  arma_conform_check( (P.n_rows != P.n_cols), "logmat(): given matrix must be square sized" );
   
   const uword N = P.n_rows;
   
@@ -268,14 +268,14 @@ inline
 bool
 op_logmat_cx::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type,T1>& expr, const uword n_iters)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type   T;
   typedef typename T1::elem_type eT;
   
   Mat<eT> S = expr.get_ref();
   
-  arma_debug_check( (S.n_rows != S.n_cols), "logmat(): given matrix must be square sized" );
+  arma_conform_check( (S.n_rows != S.n_cols), "logmat(): given matrix must be square sized" );
   
   if(S.n_elem == 0)
     {
@@ -292,7 +292,7 @@ op_logmat_cx::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename
   
   if(S.is_diagmat())
     {
-    arma_extra_debug_print("op_logmat_cx: detected diagonal matrix");
+    arma_debug_print("op_logmat_cx: detected diagonal matrix");
     
     const uword N = S.n_rows;
     
@@ -307,7 +307,7 @@ op_logmat_cx::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename
   
   if(try_sympd)
     {
-    arma_extra_debug_print("op_logmat_cx: attempting sympd optimisation");
+    arma_debug_print("op_logmat_cx: attempting sympd optimisation");
     
     // if matrix S is sympd, all its eigenvalues are positive
     
@@ -337,7 +337,7 @@ op_logmat_cx::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename
         }
       }
     
-    arma_extra_debug_print("op_logmat_cx: sympd optimisation failed");
+    arma_debug_print("op_logmat_cx: sympd optimisation failed");
     
     // fallthrough if eigen decomposition failed or an eigenvalue is <= 0
     }
@@ -352,7 +352,7 @@ inline
 bool
 op_logmat_cx::apply_common(Mat< std::complex<T> >& out, Mat< std::complex<T> >& S, const uword n_iters)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename std::complex<T> eT;
   
@@ -360,7 +360,7 @@ op_logmat_cx::apply_common(Mat< std::complex<T> >& out, Mat< std::complex<T> >&
   
   const bool schur_ok = auxlib::schur(U,S);
   
-  if(schur_ok == false)  { arma_extra_debug_print("logmat(): schur decomposition failed"); return false; }
+  if(schur_ok == false)  { arma_debug_print("logmat(): schur decomposition failed"); return false; }
   
   // NOTE: theta[0] and theta[1] not really used
   double theta[] = { 1.10e-5, 1.82e-3, 1.6206284795015624e-2, 5.3873532631381171e-2, 1.1352802267628681e-1, 1.8662860613541288e-1, 2.642960831111435e-1 };
@@ -387,19 +387,19 @@ op_logmat_cx::apply_common(Mat< std::complex<T> >& out, Mat< std::complex<T> >&
       for(uword i=2; i<=6; ++i)  { if((tau/2.0) <= theta[i])  { j2 = i; break; } }
       
       // sanity check, for development purposes only
-      arma_debug_check( (j2 > j1), "internal error: op_logmat::apply_direct(): j2 > j1" );
+      arma_conform_check( (j2 > j1), "internal error: op_logmat::apply_direct(): j2 > j1" );
       
       if( ((j1 - j2) <= 1) || (p == 2) )  { m = j1; break; }
       }
     
     const bool sqrtmat_ok = op_sqrtmat_cx::apply_direct(S,S);
     
-    if(sqrtmat_ok == false)  { arma_extra_debug_print("logmat(): sqrtmat() failed"); return false; }
+    if(sqrtmat_ok == false)  { arma_debug_print("logmat(): sqrtmat() failed"); return false; }
     
     iter++;
     }
   
-  if(iter >= n_iters)  { arma_debug_warn_level(2, "logmat(): reached max iterations without full convergence"); }
+  if(iter >= n_iters)  { arma_warn(2, "logmat(): reached max iterations without full convergence"); }
   
   S.diag() -= eT(1);
   
@@ -424,7 +424,7 @@ inline
 bool
 op_logmat_cx::helper(Mat<eT>& A, const uword m)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(A.internal_has_nonfinite())  { return false; }
   
@@ -440,7 +440,7 @@ op_logmat_cx::helper(Mat<eT>& A, const uword m)
   
   const bool eig_ok = eig_sym_helper(eigval, eigvec, tmp, 'd', "logmat()");
   
-  if(eig_ok == false)  { arma_extra_debug_print("logmat(): eig_sym() failed"); return false; }
+  if(eig_ok == false)  { arma_debug_print("logmat(): eig_sym() failed"); return false; }
   
   const vec nodes   = (eigval + 1.0) / 2.0;
   const vec weights = square(eigvec.row(0).t());
@@ -458,7 +458,7 @@ op_logmat_cx::helper(Mat<eT>& A, const uword m)
     //const bool solve_ok = solve( X, (nodes(i)*A + eye< Mat<eT> >(N,N)), A, solve_opts::fast );
     const bool solve_ok = solve( X, trimatu(nodes(i)*A + eye< Mat<eT> >(N,N)), A, solve_opts::no_approx );
     
-    if(solve_ok == false)  { arma_extra_debug_print("logmat(): solve() failed"); return false; }
+    if(solve_ok == false)  { arma_debug_print("logmat(): solve() failed"); return false; }
     
     B += weights(i) * X;
     }
@@ -475,7 +475,7 @@ inline
 void
 op_logmat_sympd::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_logmat_sympd>& in)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool status = op_logmat_sympd::apply_direct(out, in.m);
   
@@ -493,7 +493,7 @@ inline
 bool
 op_logmat_sympd::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type,T1>& expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   #if defined(ARMA_USE_LAPACK)
     {
@@ -503,16 +503,16 @@ op_logmat_sympd::apply_direct(Mat<typename T1::elem_type>& out, const Base<typen
     const unwrap<T1>   U(expr.get_ref());
     const Mat<eT>& X = U.M;
     
-    arma_debug_check( (X.is_square() == false), "logmat_sympd(): given matrix must be square sized" );
+    arma_conform_check( (X.is_square() == false), "logmat_sympd(): given matrix must be square sized" );
     
-    if((arma_config::debug) && (arma_config::warn_level > 0) && (is_cx<eT>::yes) && (sym_helper::check_diag_imag(X) == false))
+    if((arma_config::check_conform) && (arma_config::warn_level > 0) && (is_cx<eT>::yes) && (sym_helper::check_diag_imag(X) == false))
       {
-      arma_debug_warn_level(1, "logmat_sympd(): imaginary components on diagonal are non-zero");
+      arma_warn(1, "logmat_sympd(): imaginary components on diagonal are non-zero");
       }
     
     if(is_op_diagmat<T1>::value || X.is_diagmat())
       {
-      arma_extra_debug_print("op_logmat_sympd: detected diagonal matrix");
+      arma_debug_print("op_logmat_sympd: detected diagonal matrix");
       
       out = X;
       
